@@ -1,5 +1,10 @@
 testthat::context("GenericPipe")
 
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("initialize",{
 
   propertyName <- "example"
@@ -17,6 +22,16 @@ testthat::test_that("initialize",{
                          notAfterDeps)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("initialize propertyName type error",{
 
   propertyName <- NULL
@@ -26,11 +41,21 @@ testthat::test_that("initialize propertyName type error",{
   testthat::expect_error(GenericPipe$new(propertyName,
                                          alwaysBeforeDeps,
                                          notAfterDeps),
-                         "[GenericPipe][initialize][Error] Checking the type of the 'propertyName' variable: NULL",
+                         "[GenericPipe][initialize][FATAL] Checking the type of the 'propertyName' variable: NULL",
                          fixed = TRUE)
 
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("initialize alwaysBeforeDeps type error",{
 
   propertyName <- "example"
@@ -40,10 +65,20 @@ testthat::test_that("initialize alwaysBeforeDeps type error",{
   testthat::expect_error(GenericPipe$new(propertyName,
                                          alwaysBeforeDeps,
                                          notAfterDeps),
-                         "[GenericPipe][initialize][Error] Checking the type of the 'alwaysBeforeDeps' variable: NULL",
+                         "[GenericPipe][initialize][FATAL] Checking the type of the 'alwaysBeforeDeps' variable: NULL",
                          fixed = TRUE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("initialize alwaysBeforeDeps type error",{
 
   propertyName <- "example"
@@ -53,10 +88,20 @@ testthat::test_that("initialize alwaysBeforeDeps type error",{
   testthat::expect_error(GenericPipe$new(propertyName,
                                          alwaysBeforeDeps,
                                          notAfterDeps),
-                         "[GenericPipe][initialize][Error] Checking the type of the 'notAfterDeps' variable: NULL",
+                         "[GenericPipe][initialize][FATAL] Checking the type of the 'notAfterDeps' variable: NULL",
                          fixed = TRUE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("pipe",{
 
   propertyName <- "example"
@@ -70,6 +115,16 @@ testthat::test_that("pipe",{
                          fixed = TRUE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("getPropertyName",{
 
   propertyName <- "example"
@@ -84,6 +139,16 @@ testthat::test_that("getPropertyName",{
                          propertyName)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("getAlwaysBeforeDeps",{
 
   propertyName <- "example"
@@ -97,6 +162,16 @@ testthat::test_that("getAlwaysBeforeDeps",{
                          alwaysBeforeDeps)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("getNotAfterDeps",{
 
   propertyName <- "example"
@@ -110,6 +185,16 @@ testthat::test_that("getNotAfterDeps",{
                          notAfterDeps)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("setPropertyName",{
 
   propertyName <- "example"
@@ -127,6 +212,16 @@ testthat::test_that("setPropertyName",{
                          propertyNameExpected)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("setPropertyName propertyName type error",{
 
   propertyName <- "example"
@@ -140,10 +235,20 @@ testthat::test_that("setPropertyName propertyName type error",{
   propertyNameExpected <- NULL
 
   testthat::expect_error(pipe$setPropertyName(propertyNameExpected),
-                         "[GenericPipe][setPropertyName][Error] Checking the type of the 'propertyName' variable: NULL",
+                         "[GenericPipe][setPropertyName][FATAL] Checking the type of the 'propertyName' variable: NULL",
                          fixed = TRUE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("setAlwaysBeforeDeps",{
 
   propertyName <- "example"
@@ -161,6 +266,16 @@ testthat::test_that("setAlwaysBeforeDeps",{
                          alwaysBeforeDepsExpected)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("setAlwaysBeforeDeps alwaysBeforeDeps type error",{
 
   propertyName <- "example"
@@ -174,10 +289,20 @@ testthat::test_that("setAlwaysBeforeDeps alwaysBeforeDeps type error",{
   alwaysBeforeDepsExpected <- NULL
 
   testthat::expect_error(pipe$setAlwaysBeforeDeps(alwaysBeforeDepsExpected),
-                         "[GenericPipe][setAlwaysBeforeDeps][Error] Checking the type of the 'alwaysBeforeDeps' variable: NULL",
+                         "[GenericPipe][setAlwaysBeforeDeps][FATAL] Checking the type of the 'alwaysBeforeDeps' variable: NULL",
                          fixed = TRUE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("setNotAfterDeps",{
 
   propertyName <- "example"
@@ -195,6 +320,16 @@ testthat::test_that("setNotAfterDeps",{
                          notAfterDeps)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("setNotAfterDeps notAfterDeps type error",{
 
   propertyName <- "example"
@@ -208,6 +343,11 @@ testthat::test_that("setNotAfterDeps notAfterDeps type error",{
   notAfterDepsExpected <- NULL
 
   testthat::expect_error(pipe$setNotAfterDeps(notAfterDepsExpected),
-                         "[GenericPipe][setNotAfterDeps][Error] Checking the type of the 'notAfterDeps' variable: NULL",
+                         "[GenericPipe][setNotAfterDeps][FATAL] Checking the type of the 'notAfterDeps' variable: NULL",
                          fixed = TRUE)
 })
+
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
